@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dollaro" "0.2.1"
+(define-package "dollaro" "20260210.1514"
   "Simple text templates."
   '((s "1.6.0"))
   :url "https://github.com/emacsattic/dollaro"
